from tests import app


@app.route("/error-assert-query-invalid-xpath")
def error_assert_query_invalid_xpath():
    return ""
